@@ -815,7 +815,11 @@ create function "DynaRes_DAV_RES_UPLOAD_COPY" (
   in permissions varchar,
   in uid integer,
   in gid integer,
-  in auth_uid integer) returns any
+  in auth_uid integer,
+  in auth_uname varchar := null,
+  in auth_pwd varchar := null,
+  in extern integer := 1,
+  in check_locks any := 1) returns any
 {
   -- dbg_obj_princ ('DynaRes_DAV_RES_UPLOAD_COPY (', detcol_id, path_parts, source_id, what, overwrite_flags, permissions, uid, gid, auth_uid, ')');
   return -20;
@@ -829,7 +833,11 @@ create function "DynaRes_DAV_RES_UPLOAD_MOVE" (
   in source_id any,
   in what char(1),
   in overwrite_flags integer,
-  in auth_uid integer) returns any
+  in auth_uid integer,
+  in auth_uname varchar := null,
+  in auth_pwd varchar := null,
+  in extern integer := 1,
+  in check_locks any := 1) returns any
 {
   -- dbg_obj_princ ('DynaRes_DAV_RES_UPLOAD_MOVE (', detcol_id, path_parts, source_id, what, overwrite_flags, auth_uid, ')');
   return -20;
