@@ -324,7 +324,7 @@ public class VirtuosoBlob
 		   args[8] = new Long (this.bh_timestamp);
 		   //System.out.println ("vb: init read FUTURE: " + this.bh_current_page + " " + init_read_len + " " + this.bh_position);
 		   VirtuosoFuture future = connection.getFuture(VirtuosoFuture.getdata,args, -1);
-		   curr = future.nextResult(false);
+		   curr = future.nextResult();
 		   curr = (openlink.util.Vector) curr.firstElement();
 		   connection.removeFuture (future);
 		 }
@@ -386,7 +386,7 @@ public class VirtuosoBlob
 	       args[8] = new Long (this.bh_timestamp);
 	       //System.out.println ("vb: FUTURE: " + this.bh_current_page + " " + length + " " + this.bh_position);
 	       VirtuosoFuture future = connection.getFuture(VirtuosoFuture.getdata,args, -1);
-	       curr = future.nextResult(false);
+	       curr = future.nextResult();
 	       curr = (openlink.util.Vector) curr.firstElement();
 	       connection.removeFuture (future);
 	     }
