@@ -204,6 +204,9 @@ walk_db (lock_trx_t * lt, page_func_t func)
   memset (levels, 0, sizeof (levels));
 
   {
+    IN_TXN;
+    lt_threads_set_inner (lt, 1);
+    LEAVE_TXN;
     DO_SET (index_tree_t * , it, &wi_inst.wi_master->dbs_trees)
       {
 	if (it != wi_inst.wi_master->dbs_cpt_tree && !backup_key_is_ignored (&ign, it->it_key))
@@ -228,13 +231,24 @@ walk_db (lock_trx_t * lt, page_func_t func)
 	      }
 	    ITC_FAILED
 	      {
+		if (!THREAD_CURRENT_THREAD->thr_reset_ctx) /* backup-dump */
+		  {
+		    log_error ("Broken index %s", it->it_key->key_name ? it->it_key->key_name : "temp key");
+		    goto next;
+		  }
 		itc_free (itc);
+		if (!srv_have_global_lock(THREAD_CURRENT_THREAD))
+		  LEAVE_CPT (lt);
 	      }
 	    END_FAIL (itc);
+next:
 	    itc_free (itc);
 	  }
       }
     END_DO_SET()
+    IN_TXN;
+    lt_threads_set_inner (lt, 0);
+    LEAVE_TXN;
   }
 }
 
@@ -841,6 +855,7 @@ db_recover_keys (char *keys)
     }
 }
 
+int db_dd_log = 0;
 #ifdef DBG_BLOB_PAGES_ACCOUNT
 dk_hash_t * blob_pages_hash = NULL;
 void db_crash_to_log (char *mode);
@@ -848,11 +863,12 @@ void db_crash_to_log (char *mode);
 void
 db_dbg_account_add_page (dp_addr_t start)
 {
+  if (db_dd_log) return;
   if (blob_pages_hash)
     {
       if (gethash (DP_ADDR2VOID (start), blob_pages_hash))
 	{
-	  log_error ("duplicate blob db :%ld", (long) start);
+	  log_error ("duplicate blob dp :%ld", (long) start);
 	}
       sethash (DP_ADDR2VOID (start), blob_pages_hash, DP_ADDR2VOID (1));
     }
@@ -865,8 +881,8 @@ db_dbg_account_check_page_in_hash (dp_addr_t start)
     {
       if (!gethash (DP_ADDR2VOID (start), blob_pages_hash))
 	{
-	  log_error ("found a db not in the used set : %ld", (long) start);
-	  call_exit (-1);
+	  log_error ("found a dp not in the used set : %ld", (long) start);
+	  /*call_exit (-1);*/
 	}
     }
 }
@@ -896,13 +912,24 @@ db_to_log (void)
   IN_TXN;
   cli_set_new_trx (bootstrap_cli);
   LEAVE_TXN;
+  db_dd_log = 1;
   srv_dd_to_log (bootstrap_cli);
+  db_dd_log = 0;
   walk_db (bootstrap_cli->cli_trx, log_page);
 
   sqlc_hook_enable = saved_sqlc_hook_enable;
   log_info ("Database dump complete");
 #ifdef DBG_BLOB_PAGES_ACCOUNT
-  db_crash_to_log ("");
+  DO_HT (ptrlong, dp, extent_map_t *, em, wi_inst.wi_master->dbs_dp_to_extent_map)
+    {
+      extent_t * ext;
+      int type;
+      ext = EM_DP_TO_EXT (em, EXT_ROUND (dp));
+      type = EXT_TYPE (ext);
+      if (type == EXT_BLOB && !dbs_is_free_page (wi_inst.wi_master, dp))
+	db_dbg_account_check_page_in_hash (dp);
+    }
+  END_DO_HT;
 #endif
 }
 
@@ -1657,6 +1684,22 @@ bif_read_log (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args)
   return list_to_array (dk_set_nreverse (set));
 }
 
+static caddr_t
+bif_trx_w_id (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args)
+{
+  query_instance_t *qi = (query_instance_t *) qst;
+  return box_num (qi->qi_trx->lt_w_id); 
+}
+
+static caddr_t
+bif_decode_trx_w_id (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args)
+{
+  caddr_t trx_str = bif_strict_array_or_null_arg (qst, args, 0, "decode_trx_w_id");
+  caddr_t trx_id = log_cl_trx_id ((caddr_t*)trx_str);
+  long w_id = trx_id ? INT64_REF_NA (trx_id + 1) : 0;
+  return box_num (w_id);
+}
+
 void
 recovery_init (void)
 {
@@ -1666,6 +1709,8 @@ recovery_init (void)
   bif_define ("backup_close", bif_backup_close);
   bif_define ("backup_index", bif_log_index);
   bif_define ("read_log", bif_read_log);
+  bif_define ("trx_w_id", bif_trx_w_id);
+  bif_define ("decode_trx_w_id", bif_decode_trx_w_id);
 #if 0
   bif_define ("crash_recovery_log_check", bif_crash_recovery_log_check);
 #endif
