@@ -1164,7 +1164,7 @@ tn_lowest_sas_result (trans_node_t * tn, caddr_t * inst, trans_set_t * ts)
     }
   END_DO_SET();
   if (!res)
-    return;
+    res_box = ((caddr_t*)ts->ts_value)[0];
   dc_append_box (QST_BOX (data_col_t *, inst, tn->tn_output[0]->ssl_index), res_box);
   qn_result ((data_source_t*)tn, inst, QST_INT (inst, tn->clb.clb_nth_set) - 1);
   if (QST_INT (inst, tn->src_gen.src_out_fill) >= QST_INT (inst, tn->src_gen.src_batch_size))
@@ -1292,9 +1292,11 @@ tn_results (trans_node_t * tn, caddr_t * inst)
 	  SRC_IN_STATE ((data_source_t*)tn, inst) = NULL;
 	  return;
 	}
+      if (!itcl->itcl_param_rows[nth])
+	continue;
       ts = (trans_set_t*) itcl->itcl_param_rows[nth][0];
-      if (!ts->ts_result)
-	{
+      if (!ts || !ts->ts_result)
+	    {
 	  QST_INT (inst, tn->clb.clb_nth_set)++;
 	  continue;
 	}
@@ -1405,6 +1407,11 @@ trans_node_start (trans_node_t * tn, caddr_t * inst, caddr_t * state, int n_sets
     DO_BOX (state_slot_t *, ssl, inx, tn->tn_input)
       {
 	in[inx] = t_full_box_copy_tree (qst_get (inst, ssl));
+	if (DV_DB_NULL == DV_TYPE_OF (in[inx]))
+	  {
+	    cl_select_save_env ((table_source_t *)tn, itcl, inst, (cl_op_t*)NULL, nth);
+	    return;
+	  }
       }
     END_DO_BOX;
     if (tn->tn_target)
@@ -1413,10 +1420,16 @@ trans_node_start (trans_node_t * tn, caddr_t * inst, caddr_t * state, int n_sets
 	DO_BOX (state_slot_t *, ssl, inx, tn->tn_target)
 	  {
 	    target[inx] = t_full_box_copy_tree (qst_get (inst, ssl));
+	    if (DV_DB_NULL == DV_TYPE_OF (target[inx]))
+	      {
+		cl_select_save_env ((table_source_t *)tn, itcl, inst, (cl_op_t*)NULL, nth);
+		return;
+	      }
 	  }
 	END_DO_BOX;
 	in = t_list (2, in, target);
       }
+
     place = (trans_set_t**) id_hash_get (sets, (caddr_t)&in);
     if (!place)
       {
